@@ -121,8 +121,12 @@ else:
 TRAIN_LEN = len(x_train)
 
 if DEBUG:
-    x_train = x_train[:TRAIN_LEN//10]
-    y_train = y_train[:TRAIN_LEN//10]
+    x_train = x_train[:TRAIN_LEN//10, :140]
+    y_train = y_train[:TRAIN_LEN//10]  # y just all pass, they are labels
+    x_valid = x_valid[:, :140]
+    # y_valid = y_valid[:] # it just one dimention
+    x_test  = x_test[:, :140]
+
     TRAIN_LEN = TRAIN_LEN//10
 
 # +
@@ -130,7 +134,7 @@ train_dataset = (
     tf.data.Dataset
     .from_tensor_slices((x_train, y_train))
     .repeat()
-    .shuffle(TRAIN_LEN)
+    .shuffle(2048)
     .batch(BATCH_SIZE)
     .prefetch(AUTO)
 )
@@ -138,7 +142,7 @@ train_dataset = (
 valid_dataset = (
     tf.data.Dataset
     .from_tensor_slices((x_valid, y_valid))
-    .shuffle(len(x_valid))
+    .shuffle(1024)
     .batch(BATCH_SIZE)
     .cache()
     .prefetch(AUTO)
