@@ -1,13 +1,20 @@
+import os
+
+import pandas as pd
 import tensorflow as tf
 from tensorflow.keras.layers import Dense, Dropout, Input
+from tensorflow.keras.losses import BinaryCrossentropy
 from tensorflow.keras.models import Model
 from tensorflow.keras.optimizers import Adam
 
 import transformers
+from kaggle_runner import may_debug
 from kaggle_runner.callbacks import ReduceLROnPlateauLogCBs
-from kaggle_runner.datasets.bert import x_valid, y_valid
-from kaggle_runner.metrics.metrics import matthews_correlation_aux_stripper
+from kaggle_runner.datasets.bert import (DATA_PATH, test_dataset, x_valid,
+                                         y_valid)
+from kaggle_runner.metrics.metrics import matthews_correlation
 from kaggle_runner.utils.tpu import strategy
+from kaggle_runner.utils.wrapper import size_decorator
 
 # ### learn from 1st place solution
 # Custom head for BERT, XLNet and GPT2 and Bucket Sequencing Collator
@@ -37,7 +44,7 @@ def _build_distilbert_model_adv(transformer, max_len=512):
     https://www.kaggle.com/c/jigsaw-unintended-bias-in-toxicity-classification/discussion/103280
     """
 
-    return _build_distilbert_model(transformer, max_len=512)
+    return _build_distilbert_model(transformer, max_len=max_len)
 
 def _build_distilbert_model(transformer, max_len=512):
     input_word_ids = Input(shape=(max_len,), dtype=tf.int32, name="input_word_ids")
@@ -51,24 +58,34 @@ def _build_distilbert_model(transformer, max_len=512):
     model = Model(inputs=input_word_ids, outputs=out)
 
     model.compile(Adam(lr=1.5e-5),
-                  loss='binary_crossentropy',
-                  metrics=[matthews_correlation_aux_stripper])
+                  loss=size_decorator(BinaryCrossentropy(reduction=
+                                                         tf.keras.losses.Reduction.SUM
+                                                         , label_smoothing=0.2)),
+                  #'binary_crossentropy',
+                  metrics=[size_decorator(matthews_correlation)])
 
     return model
 
 
-def build_distilbert_model_singleton():
+def build_distilbert_model_singleton(max_len):
     global __model_distilbert
 
-    if __model_distilbert is None:
+    #if __model_distilbert is None:
+
+    if True:
         if strategy is None:
             transformer_layer = transformers.TFDistilBertModel.\
             from_pretrained('distilbert-base-multilingual-cased')
-            __model_distilbert = _build_distilbert_model_adv(transformer_layer, max_len=512)
+            __model_distilbert = _build_distilbert_model_adv(transformer_layer, max_len=max_len)
         else:
             with strategy.scope():
                 transformer_layer = transformers.TFDistilBertModel.\
                 from_pretrained('distilbert-base-multilingual-cased')
-                __model_distilbert = _build_distilbert_model_adv(transformer_layer, max_len=512)
+                __model_distilbert = _build_distilbert_model_adv(transformer_layer, max_len=max_len)
 
     return __model_distilbert
+
+def get_test_result(self, test_dataset=test_dataset, data_path=DATA_PATH):
+    sub = pd.read_csv(os.path.join(data_path , 'sample_submission.csv'))
+    sub['toxic'] = self.model_distilbert.predict(test_dataset, verbose=1)[:,0]
+    sub.to_csv('submission.csv', index=False)
