@@ -1,13 +1,21 @@
 import numpy as np
+import tensorflow as tf
 import tensorflow.keras.backend as K
-
 import torch
+
 from kaggle_runner import may_debug
 
 
 def matthews_correlation_aux_stripper(y_true, y_pred):
-    may_debug()
-    y_pred = y_pred[:,0]
+    # may_debug()
+    # y_pred = y_pred[:,0]
+    ts = y_true.shape
+    ps = y_pred.shape
+
+    if len(ps) > len(ts) or (
+            (ps[1] > ts[1]) if ts[1] is not None else False):
+        may_debug()
+        y_pred = y_pred[:,0]
 
     return matthews_correlation(y_true, y_pred)
 
